@@ -2,6 +2,8 @@
 # Inquiry : sunkyeong.lee@concentrix.com / sunkyong9768@gmail.com
 
 from copy import Error
+# from actModuler import *
+# from actRunner import *
 from .actModuler import *
 from .actRunner import *
 import time
@@ -91,4 +93,33 @@ def Retrive_by_RS(start_date, end_date, period, jsonLocation, rsInput, tbColumn,
                 print("Index Error")
                 continue
 
-            stackTodb(sample, dbTableName)
\ No newline at end of file
+            stackTodb(sample, dbTableName)
+
+## 22.04.30 added
+def Retrive_by_RS_breakdown(start_date, end_date, period, jsonLocation, jsonLocation_breakdown, rsInput, tbColumn, dbTableName, epp, limit):
+    dateCaller = dateGenerator(start_date, end_date, period)
+    # site_code_rs = False
+    # tbColumn = tbColumnGenerator(tbColumn, False, True, True, site_code_rs)
+    tbColumn = ["rs_name", "dimension", "breakdown", "period", "start_date", "end_date", "is_epp", "is_epp_integ"]
+    
+    startDate = dateCaller[0]
+    endDate = dateCaller[1]
+
+    rsList = returnRsList(epp, rsInput)
+
+    for i in range(len(startDate)):
+        for j in range(len(rsList)):
+            try:
+                sample = refineRsIDChange_breakdown(startDate[i], endDate[i], jsonLocation, jsonLocation_breakdown, rsList[j], period, tbColumn, epp, limit)
+
+            except KeyError:
+                print("Server Error Occurred")
+                continue
+
+            except IndexError:
+                print("Index Error")
+                continue
+
+            stackTodb(sample, dbTableName)
+
+
